@@ -7,6 +7,7 @@ import unittest
 import numpy as np
 import numpy.testing as npt
 import xarray as xr
+
 from punpy import MeasurementFunction,MCPropagation
 
 """___Authorship___"""
@@ -251,8 +252,8 @@ class TestMeasurementFunction(unittest.TestCase):
         # print(u_y_rand,L0data)
         mask = np.where(
             (
-                    (L1data["wavelength"].values < 1350)
-                    | (L1data["wavelength"].values > 1450)
+                (L1data["wavelength"].values < 1350)
+                | (L1data["wavelength"].values > 1450)
             )
         )
 
@@ -273,7 +274,7 @@ class TestMeasurementFunction(unittest.TestCase):
             u_y_tot[mask] / y[mask] * 100,
             rtol=0.05,
             atol=0.05,
-            )
+        )
 
     def test_hypernets_expand(self):
         prop = MCPropagation(3000, dtype="float32", parallel_cores=1, verbose=False)
@@ -291,19 +292,25 @@ class TestMeasurementFunction(unittest.TestCase):
             yvariable="irradiance",
             yunit="W m^-2",
             corr_between=None,
-            param_fixed=[False,False,False,True,False],
+            param_fixed=[False, False, False, True, False],
             broadcast_correlation="rand",
         )
 
         hmf.setup(0.1)
 
-        ds_tot = hmf.propagate_ds_total(L0data, calib_data, store_unc_percent=True, expand=True)
-        npt.assert_allclose(ds_tot["err_corr_tot_irradiance"].values[:9,:9], np.eye(9), atol=0.07)
-
-        ds_tot = hmf.propagate_ds_total(L0data, calib_data, store_unc_percent=True, expand=False)
-        npt.assert_allclose(ds_tot["err_corr_tot_irradiance"].values[:9,:9], np.ones((9,9)), atol=0.07)
-
+        ds_tot = hmf.propagate_ds_total(
+            L0data, calib_data, store_unc_percent=True, expand=True
+        )
+        npt.assert_allclose(
+            ds_tot["err_corr_tot_irradiance"].values[:9, :9], np.eye(9), atol=0.07
+        )
 
+        ds_tot = hmf.propagate_ds_total(
+            L0data, calib_data, store_unc_percent=True, expand=False
+        )
+        npt.assert_allclose(
+            ds_tot["err_corr_tot_irradiance"].values[:9, :9], np.ones((9, 9)), atol=0.07
+        )
 
     def test_hypernets_repeat_dim(self):
         prop = MCPropagation(3000, dtype="float32", parallel_cores=0, verbose=False)
